@@ -58,7 +58,7 @@ char* stripinvalidtag(char* xml, int len) 	//ГРЯЗНЫЙ ХАК нужен ч
 }
 
 
-Item* xmlparse(const char* xml, int len) //xml строка с xml len ее размер в байтах
+Item* xmlparse(const char* xml, int len, std::string& errmsg) //xml строка с xml len ее размер в байтах
 {
     XML_Parser parser;
     void* ret;
@@ -72,7 +72,8 @@ Item* xmlparse(const char* xml, int len) //xml строка с xml len ее ра
     int retcode = XML_Parse(parser, xml, len, XML_TRUE); //собственно парсинг
     if (retcode == XML_STATUS_ERROR)
     {
-	kLogPrintf("XML Error: %s\n", XML_ErrorString(XML_GetErrorCode(parser)));
+	    kLogPrintf("XML Error: %s\n", XML_ErrorString(XML_GetErrorCode(parser)));
+        errmsg = std::string("XML error:") + std::string(XML_ErrorString(XML_GetErrorCode(parser)));
     }
     XML_ParserFree(parser);
     while (!curitem.empty())
