@@ -31,6 +31,7 @@
 //Названия пунктов меню "File"
 #define M_NEXT_HOST			"Next BOINC host"
 #define M_CONFIG_HOSTS			"Configure host list"
+#define M_VIEW_STATS			"View Statistics"
 #define M_RUN_BENCHMARKS		"Run CPU benchmarks"
 #define M_QUIT				"Quit boinctui"
 //Названия пунктов меню "View"
@@ -59,6 +60,8 @@
 #define M_CONNECT_MANAGER		"Connect to account manager"
 #define M_SYNCHRONIZE_MANAGER		"Synchronize with manager"
 #define M_DISCONNECT_MANAGER		"Stop using account manager"
+//Меню списка менеджеров
+#define M_ADD_NEW_MGR			"Add new account manager"
 //Названия пунктов подменю "Projects/Имя проекта"
 #define M_UPDATE_PROJECT		"Update project"
 #define M_SUSPEND_PROJECT		"Suspend project"
@@ -228,6 +231,7 @@ FileSubMenu::FileSubMenu(NRect rect) : NMenu(rect)
 {
     additem(M_NEXT_HOST,"  N");
     additem(M_CONFIG_HOSTS,"  C");
+    additem(M_VIEW_STATS,"  V");
     additem(M_RUN_BENCHMARKS,"");
     additem(M_QUIT,"  Q");
     additem(NULL,NULL);
@@ -241,6 +245,8 @@ bool FileSubMenu::action()
 	putevent(new NEvent(NEvent::evKB, 'N')); //создаем событие иммитирующее нажатие 'N'
     if ( strcmp(item_name(current_item(menu)),M_CONFIG_HOSTS) == 0 )
 	putevent(new NEvent(NEvent::evKB, 'C')); //создаем событие иммитирующее нажатие 'C'
+    if ( strcmp(item_name(current_item(menu)),M_VIEW_STATS) == 0 )
+	putevent(new NEvent(NEvent::evKB, 'V')); //создаем событие иммитирующее нажатие 'V'
     if ( strcmp(item_name(current_item(menu)),M_RUN_BENCHMARKS) == 0 )
 	putevent(new TuiEvent(evBENCHMARK)); //NEvent(NEvent::evPROG, 5)); //создаем событие запускающее бенчмарк
     if ( strcmp(item_name(current_item(menu)),M_QUIT) == 0 )
@@ -837,6 +843,7 @@ void ProjectAllListSubMenu::eventhandle(NEvent* ev) 	//обработчик со
 ProjectAccMgrSubMenu::ProjectAccMgrSubMenu(NRect rect, Srv* srv) : NMenu(rect)
 {
     this->srv = srv;
+    //стандартные менеджеры
     if (srv != NULL)
     {
 	srv->updateallprojects();
@@ -855,6 +862,22 @@ ProjectAccMgrSubMenu::ProjectAccMgrSubMenu(NRect rect, Srv* srv) : NMenu(rect)
 	    }
 	}
     }
+    //менеджеры из конфига
+    Item* boinctui_cfg = gCfg->getcfgptr();
+    if (boinctui_cfg != NULL)
+    {
+	std::vector<Item*> mgrlist = boinctui_cfg->getItems("accmgr");
+	std::vector<Item*>::iterator it;
+	for (it = mgrlist.begin(); it != mgrlist.end(); it++)
+	{
+	    Item* name = (*it)->findItem("name");
+	    if (name != NULL)
+		additem(name->getsvalue(),"");
+	}
+    }
+    //пункт добавить новый менеджер
+    additem("","");
+    additem(M_ADD_NEW_MGR,"");
     additem(NULL,NULL);
 }
 
@@ -863,7 +886,12 @@ bool ProjectAccMgrSubMenu::action()
 {
     putevent(new NEvent(NEvent::evKB, KEY_F(9))); //создаем событие закрывающее меню
     if (srv != NULL)
-	putevent(new TuiEvent(evADDACCMGR, srv, item_name(current_item(menu)))); //создаем событие открвыающее форму менеджера
+    {
+	if (strcmp(item_name(current_item(menu)), M_ADD_NEW_MGR) != 0)
+	    putevent(new TuiEvent(evADDACCMGR, srv, item_name(current_item(menu)))); //создаем событие открвыающее форму менеджера
+	else
+	    putevent(new TuiEvent(evADDACCMGR, srv, "Unnamed")); //создаем событие открвыающее форму менеджера
+    }
     return true;
 }
 
@@ -885,12 +913,6 @@ void ProjectAccMgrSubMenu::eventhandle(NEvent* ev) 	//обработчик со
 	    case KEY_LEFT:
 		putevent(new NEvent(NEvent::evKB, 27)); //закрыть это подменю
 		break;
-	    case 27:
-		if ( !items.empty()/* > 1*/ ) //1 из-за скроллбара
-		    destroysubmenu();
-		else
-		    ev->done = false; //пусть обрабатывает владелец
-		break;
 	    default:
 		ev->done = false; //нет реакции на этот код
 	} //switch
