@@ -38,7 +38,8 @@ enum TuiEventType
     evTASKINFO,		//генерируется когда нужно открыть окно детальной информации о задаче
     evTASKSELECTORON,	//генерируется когда селектор задач становится видимым
     evTASKSELECTOROFF,	//генерируется когда селектор задач становится скрытым
-    evASCIIMODECHANGE	//генерируется при переключении режима ASCII рамок
+    evASCIIMODECHANGE,	//генерируется при переключении режима ASCII рамок
+    evPOPUPMSG          //генерируется когда нужно открыть попап сообщение
 };
 
 
@@ -74,6 +75,11 @@ class TuiEvent : public NEvent //класс программных событи
     {
 	this->idata1 = mode;
     };
+    TuiEvent(TuiEventType type, const char* caption, const char* msg) : NEvent(evPROG, type) //событие попап сообщения
+    {
+        this->sdata1 = caption;
+        this->sdata2 = msg;
+    };
     virtual ~TuiEvent() { /*kLogPrintf("~TuiEvent()\n");*/ };
     Srv*		srv;
     std::string		sdata1; //произвольная строка
@@ -83,4 +89,4 @@ class TuiEvent : public NEvent //класс программных событи
 };
 
 
-#endif //TUIEVENT_H
\ No newline at end of file
+#endif //TUIEVENT_H
